#
# spec file for package obs-service-go_modules
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

# Macros from obs-service_tar_scm
%if 0%{?suse_version} >= 1315 || 0%{?fedora_version} >= 29
%bcond_without python3
%else
%bcond_with    python3
%endif

# This list probably needs to be extended
# logic seems to be if python < 2.7 ; then needs_external_argparse ; fi
%if (0%{?centos_version} == 6) || (0%{?suse_version} && 0%{?suse_version} < 1315) || (0%{?fedora_version} && 0%{?fedora_version} < 26)
%bcond_without needs_external_argparse
%else
%bcond_with    needs_external_argparse
%endif

%if %{with python3}
%define use_python python3
%define use_test   test3
%else
%define use_python python
%define use_test   test
%endif

%define service go_modules

Name:           obs-service-%{service}
Summary:        An OBS source service: Download, verify and vendor Go module dependencies
License:        GPL-2.0-or-later
Group:          Development/Tools/Building
Url:            https://github.com/openSUSE/obs-service-%{service}
Version:        0.3.0
Release:        bp153.1.16
Source:         %{name}-%{version}.tar.gz
%if %{with needs_external_argparse}
BuildRequires:  %{use_python}-argparse
%endif
%if %{with python3}
BuildRequires:  %{use_python}
# Fix missing Requires in python3-pbr in Leap42.3
BuildRequires:  %{use_python}-setuptools
%endif
BuildRequires:  go-md2man
Requires:       go >= 1.11
Requires:       gzip
Requires:       tar
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
An OBS Source Service that will download,
verify and vendor Go module dependency sources.

Using go.mod and go.sum present in a Go application,
the source service will call Go tools in sequence:

go mod download
go mod verify
go mod vendor

Then create a vendor.tar.gz populated with the contents of
vendor/

%prep
%setup -q

%build

%install
mkdir -p %{buildroot}%{_prefix}/lib/obs/service
mkdir -p %{buildroot}%{_prefix}/lib/obs/service
install -m 0755 go_modules %{buildroot}%{_prefix}/lib/obs/service
install -m 0644 go_modules.service %{buildroot}%{_prefix}/lib/obs/service

# Build the man page from markdown documentation.
go-md2man -in README.md -out %{name}.1

# Install the man page.
install -D -m 0644 %{name}.1 "%{buildroot}/%{_mandir}/man1/%{name}.1"
rm %{name}.1

%files
%defattr(-,root,root)
%doc README.md
%license LICENSE
%dir %{_prefix}/lib/obs
%{_prefix}/lib/obs/service
%{_mandir}/man1/%{name}.1%{?ext_man}

%changelog
* Mon Sep  2 2019 jkowalczyk@suse.com
- Update to version 0.3.0:
  * Add check for version agreement with .spec to archive autodetection
  * README add example _service configuration
  * README update FAQ entries regarding Go module cache
  * README update example to reflect current log output
  * Add Go source archive autodetection based on RPM spec file name
  * Add missing parameter archive to definition go_modules.service
  * Add exception handling around shutil.rmtree for extracted archive
  * README fix hyperlink
  * README cite openSUSE packages built using obs-service-go_modules
  * Reduce python module __doc__ from full copy to subset of README
  * Packaging tar_scm service use revision instead of version to
    fix use of _servicedata for changelog generation
* Mon Aug  5 2019 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update upstream repository location now in openSUSE organization
* Mon Aug  5 2019 jkowalczyk@suse.com
- Update to version 0.2.1:
  * README documentation improvements
* Thu Aug  1 2019 Jeff Kowalczyk <jkowalczyk@suse.com>
- obs-service-go_modules (0.2.0 released 2019/08/01) is the first
  packaged release for review and feedback. This OBS Source Service
  will download, verify and vendor Go module dependencies expressed
  in the file go.mod.  By vendoring all dependencies during the OBS
  Source Service stage, go build commands can run in the offline
  OBS build environment. This initial version:
  * Tested by packaging devel:languages:go/hugo, which has the
    typical Go application unpacked layout containing go.mod at:
    hugo-0.56.3/go.mod
  * Supports tar.gz archives in the form
    hugo-0.56.3.tar.gz -> hugo-0.56.3/
    Other archive format and layout support to be added as needed
  * Produces vendor.tar.gz
    vendor.cpio archive support planned
  * Replace print() with logging facilities
  * Fix indentation for cmd_go_mod() return values
  * Return non-zero exit codes on failure
